<?php

echo '<pre>';

// To send an SMS you'll only need to call an URL:
// place this in a function or a class (or use the BIP API class).
//
// The example below shows the most basic API call usage and
// basic error handling we strongly suggest.
//
// IMPORTANT: always take care of UTF-8 coding! To use
// a different encoding you may use mb_convert_encoding():
//
//   $message = mb_convert_encoding( $message, 'utf-8', 'iso-8859-2' );
//   (second parameter is the target codepage, the third one is the source codepage)

$url = 
   'http://api.bipkampany.hu/sendsms' .
   '?email='     . rawurlencode( 'email@example.com' ) . 
   '&password='  . rawurlencode( 'password' ) . 
   '&message='   . rawurlencode( 'Hello World!' ) .
   '&number=36301234567' . 
   '&senderid=BipKampany'
;

simpleLogging( $url );
$result = file_get_contents( $url );

if ( $result === false ) {

  errorMessage(
    'BIP API call error: API not available (network issue?)',
    array( 'url' => $url )
  );

}
else {

  parse_str( $result, $resultparts );

  switch ( $resultparts['result'] ) {

    case 'OK':
      // SMS submit was successful
      simpleLogging('OK');
      break;

    case 'ERR':
      // details are in $resultparts['code'] and $resultparts['message']
      errorMessage( 'SMS submit error', $resultparts );
      break;

  }

}

echo '</pre>';

function errorMessage( $message, $result = array() ) {

  $body = var_export( $result, true );
  echo '<pre>' . $body . '</pre>';

  mail( 
    'developer@example.com', 
    $message,
    $body
  );

  simpleLogging( $body );

}

function simpleLogging( $string ) {

  $f = fopen( 'bipapi-' . date('Y-m') . '.txt', 'a' );
  fputs( $f, date("Y-m-d H:i:s") . ' ' . $string . "\n" );
  fclose( $f );

}

?>